Welcome to mwatershed's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :hidden:

   install
   tutorials/funlib_comparison
   api
   contributing
   authors

.. include:: ../../README.md
   :parser: myst_parser.sphinx_